SRComp CLI
==========

|Build Status| |Docs Status|

A set of command-line tools for operating SRComp at a competition and for
working with compstate repositories.

Usage
-----

**Install**:

.. code:: shell

    pip install -U pip setuptools wheel
    pip install sr.comp.cli

Bash completions are also available, see the ``bash-completion`` file in the
root of the repo.

Development
-----------

**Install**:

.. code:: shell

    pip install -e .


**Test**:
``./run-tests``


.. |Build Status| image:: https://circleci.com/gh/PeterJCLaw/srcomp-cli.svg?style=svg
   :target: https://circleci.com/gh/PeterJCLaw/srcomp-cli

.. |Docs Status| image:: https://readthedocs.org/projects/srcomp-cli/badge/?version=latest
   :target: https://srcomp-cli.readthedocs.org/
